#ifndef GUARD_DUNGEON_CUTSCENE_H 
#define GUARD_DUNGEON_CUTSCENE_H

#include "structs/dungeon_entity.h"

void ArticunoPostStoryPreFightDialogue(void);
void ArticunoPreFightDialogue(void);
void ArticunoReFightDialogue(void);
void CelebiJoinDialogue(void);
void DeoxysPreFightDialogue(void);
void DummyFightDialogue(void);
void EnteiPostStoryPreFightDialogue(void);
void EnteiPreFightDialogue(void);
void EnteiReFightDialogue(void);
void GroudonPostStoryPreFightDialogue(void);
void GroudonPreFightDialogue(void);
void GroudonReFightDialogue(void);
void HoOhPreFightDialogue(void);
void HoOhReFightDialogue(void);
void JirachiPreFightDialogue(void);
void JirachiReFightDialogue(void);
void KyogrePreFightDialogue(void);
void LatiosPreFightDialogue(void);
void LatiosReFightDialogue(void);
void LugiaPreFightDialogue(void);
void MagmaCavernMidDialogue(void);
void MedichamRescueDialogue(void);
void MewtwoPreFightDialogue(void);
void MewtwoReFightDialogue(void);
void MoltresPostStoryPreFightDialogue(void);
void MoltresPreFightDialogue(void);
void MoltresReFightDialogue(void);
void RaikouPostStoryPreFightDialogue(void);
void RaikouPreFightDialogue(void);
void RaikouReFightDialogue(void);
void RayquazaPostStoryPreFightDialogue(void);
void RayquazaPreFightDialogue(void);
void RayquazaReFightDialogue(void);
void RegicePreFightDialogue(void);
void RegirockPreFightDialogue(void);
void RegisteelPreFightDialogue(void);
void SkarmoryPreFightDialogue(void);
void SkarmoryReFightDialogue(void);
void SmeargleRescueDialogue(void);
void SuicunePostStoryPreFightDialogue(void);
void SuicunePreFightDialogue(void);
void SuicuneReFightDialogue(void);
void TeamMeaniesPreFightDialogue(void);
void TeamMeaniesReFightDialogue(void);
void ZapdosPostStoryPreFightDialogue(void);
void ZapdosPreFightDialogue(void);
void ZapdosReFightDialogue(void);
void nullsub_100(u8, u8, u8);
void sub_8086B14(void);
void sub_8086B94(void);
void sub_8086BDC(u8, s32); // TODO: should be u8
void sub_8086E40(void);
void sub_8086E9C(void);
void sub_8086F00(void);
void sub_8086F54(u8, u8);
void sub_8087130(void);
void sub_8087230(void);
void sub_808729C(void);
void sub_8087334(u8, u8);
void sub_80877E8(void);
void sub_8087848(void);
void sub_80878F4(u8, u8);
void sub_8087F54(void);
void sub_8087FB4(void);
void sub_8087FF8(void);
void sub_8088088(u8, u8);
void sub_80885A0(void);
void sub_80885C4(void);
void sub_8088608(void);
void sub_8088618(void);
void sub_808862C(void);
void sub_80886C4(void);
void sub_808875C(void);
void sub_8088818(u8, u8);
void sub_8088DC0(void);
void sub_8088E5C(void);
void sub_8089168(void);
void sub_80892C8(void);
void sub_8089328(void);
void sub_80893B4(u8, u8);
void sub_808970C(void);
void sub_808974C(void);
void sub_8089788(Entity *entity, u8, u8);
void sub_80897F0(void);
void sub_8089878(void);
void sub_80898E4(void);
void sub_8089914(void);
void sub_8089978(void);
void sub_8089A00(u8, u8);
void sub_8089C44(void);
void sub_8089C90(void);
void sub_8089CFC(u8, u8);
void sub_8089EFC(void);
void sub_8089F44(void);
void sub_8089F8C(void);
void sub_8089FF0(u8, u8);
void sub_808A264(void);
void sub_808A2C0(void);
void sub_808A308(void);
void sub_808A36C(u8, u8);
void sub_808A608(void);
void sub_808A668(void);
void sub_808A6E8(u8, u8);
void sub_808A9E4(void);
void sub_808AA3C(void);
void sub_808AA94(void);
void sub_808AAF0(u8, u8);
void sub_808AC3C(void);
void sub_808ACC0(void);
void sub_808AD48(void);
void sub_808ADCC(void);
void sub_808AE54(u8, u8, DungeonPos *pos);
void sub_808AEC8(u8, u8, DungeonPos *pos);
void sub_808AF3C(u8, u8, DungeonPos *pos);
void sub_808AFB0(u8);
void sub_808B030(u8);
void sub_808B0B0(u8);
void sub_808B2F4(void);
void sub_808B35C(void);
void sub_808B3E4(u8, u8, u8);
void sub_808BDEC(void);
void sub_808BE70(u8, u8, u8);
void sub_808C10C(void);
void sub_808C1A4(u8, u8, u8);
void sub_808C3A0(void);
void sub_808C414(u8, u8, u8);
void sub_808C5C0(void);
void sub_808C938(void);
void sub_808C948(Entity *entity, u8);
void sub_808C998(void);
void sub_808C9C4(void);
void sub_808CB5C(void);
void sub_808CBB0(void);
void sub_808CD44(void);
void sub_808CD9C(void);

#endif /* ifndef GUARD_DUNGEON_CUTSCENE_H */
